@@ -81,7 +81,7 @@ Read_Comments( void )
 	}
 
 	/* separate card's id mnemonic */
-	Strlcpy( ain, line_buf, 3 );
+	Strlcpy( ain, line_buf, sizeof(ain) );
 
 	/* Check for incorrect mnemonic */
 	if( (strcmp(ain, "CM") != 0) && (strcmp(ain, "CE") != 0) )
@@ -116,34 +116,34 @@ Read_Geometry( void )
 
   /* Memory allocation for temporary buffers */
   mreq = (size_t)data.npm * sizeof(double);
-  mem_realloc( (void *)&save.xtemp,  mreq, "in input.c" );
-  mem_realloc( (void *)&save.ytemp,  mreq, "in input.c" );
-  mem_realloc( (void *)&save.ztemp,  mreq, "in input.c" );
-  mem_realloc( (void *)&save.bitemp, mreq, "in input.c" );
+  mem_realloc( (void **)&save.xtemp,  mreq, "in input.c" );
+  mem_realloc( (void **)&save.ytemp,  mreq, "in input.c" );
+  mem_realloc( (void **)&save.ztemp,  mreq, "in input.c" );
+  mem_realloc( (void **)&save.bitemp, mreq, "in input.c" );
   if( data.n > 0 )
   {
 	mreq = (size_t)data.n * sizeof(double);
-	mem_realloc( (void *)&save.sitemp, mreq, "in input.c" );
+	mem_realloc( (void **)&save.sitemp, mreq, "in input.c" );
   }
 
   /* Memory allocation for primary interacton matrix. */
   mreq = (size_t)(data.np2m * (data.np + 2 * data.mp)) * sizeof(complex double);
-  mem_realloc( (void *)&cm, mreq, "in input.c" );
+  mem_realloc( (void **)&cm, mreq, "in input.c" );
 
   /* Memory allocation for current buffers */
   mreq = (size_t)data.npm * sizeof( double);
-  mem_realloc( (void *)&crnt.air, mreq, "in input.c" );
-  mem_realloc( (void *)&crnt.aii, mreq, "in input.c" );
-  mem_realloc( (void *)&crnt.bir, mreq, "in input.c" );
-  mem_realloc( (void *)&crnt.bii, mreq, "in input.c" );
-  mem_realloc( (void *)&crnt.cir, mreq, "in input.c" );
-  mem_realloc( (void *)&crnt.cii, mreq, "in input.c" );
+  mem_realloc( (void **)&crnt.air, mreq, "in input.c" );
+  mem_realloc( (void **)&crnt.aii, mreq, "in input.c" );
+  mem_realloc( (void **)&crnt.bir, mreq, "in input.c" );
+  mem_realloc( (void **)&crnt.bii, mreq, "in input.c" );
+  mem_realloc( (void **)&crnt.cir, mreq, "in input.c" );
+  mem_realloc( (void **)&crnt.cii, mreq, "in input.c" );
   mreq = (size_t)data.np3m * sizeof( complex double);
-  mem_realloc( (void *)&crnt.cur, mreq, "in input.c" );
+  mem_realloc( (void **)&crnt.cur, mreq, "in input.c" );
 
   /* Memory allocation for loading buffers */
   mreq = (size_t)data.npm * sizeof(complex double);
-  mem_realloc( (void *)&zload.zarray, mreq, "in input.c" );
+  mem_realloc( (void **)&zload.zarray, mreq, "in input.c" );
 
   /* Save segment and patch data for freq scaling */
   if( data.n > 0 )
@@ -194,7 +194,7 @@ Read_Commands( void )
   double tmp1, tmp2, tmp3, tmp4, tmp5, tmp6;
   int
 	mpcnt, itmp1, itmp2, itmp3, itmp4,
-	ain_num;     /* My addition, ain mnemonic as a number */
+	ain_num;   /* My addition, ain mnemonic as a number */
   size_t mreq; /* My addition, size req. for malloc's   */
 
   /* initializations etc from original fortran code */
@@ -243,12 +243,12 @@ Read_Commands( void )
 
   /* Allocate some buffers */
   mreq = (size_t)data.np2m * sizeof(int);
-  mem_realloc( (void *)&save.ip, mreq, "in input.c" );
+  mem_realloc( (void **)&save.ip, mreq, "in input.c" );
 
   /* Memory allocation for symmetry array */
   smat.nop = netcx.neq/netcx.npeq;
   mreq = (size_t)(smat.nop * smat.nop) * sizeof( complex double);
-  mem_realloc( (void *)&smat.ssx, mreq, "in input.c" );
+  mem_realloc( (void **)&smat.ssx, mreq, "in input.c" );
 
   /* main input section, exits at various points */
   /* depending on error conditions or end of job */
@@ -307,11 +307,11 @@ Read_Commands( void )
 		  {
 			vsorc.nvqd++;
 			mreq = (size_t)vsorc.nvqd * sizeof(int);
-			mem_realloc( (void *)&vsorc.ivqd, mreq, "in input.c" );
-			mem_realloc( (void *)&vsorc.iqds, mreq, "in input.c" );
+			mem_realloc( (void **)&vsorc.ivqd, mreq, "in input.c" );
+			mem_realloc( (void **)&vsorc.iqds, mreq, "in input.c" );
 			mreq = (size_t)vsorc.nvqd * sizeof(complex double);
-			mem_realloc( (void *)&vsorc.vqd, mreq, "in input.c" );
-			mem_realloc( (void *)&vsorc.vqds, mreq, "in input.c" );
+			mem_realloc( (void **)&vsorc.vqd, mreq, "in input.c" );
+			mem_realloc( (void **)&vsorc.vqds, mreq, "in input.c" );
 			{
 			  int indx = vsorc.nvqd-1;
 
@@ -331,9 +331,9 @@ Read_Commands( void )
 			/* Else, applied E field */
 			vsorc.nsant++;
 			mreq = (size_t)vsorc.nsant * sizeof(int);
-			mem_realloc( (void *)&vsorc.isant, mreq, "in input.c" );
+			mem_realloc( (void **)&vsorc.isant, mreq, "in input.c" );
 			mreq = (size_t)vsorc.nsant * sizeof(complex double);
-			mem_realloc( (void *)&vsorc.vsant, mreq, "in input.c" );
+			mem_realloc( (void **)&vsorc.vsant, mreq, "in input.c" );
 			{
 			  int indx = vsorc.nsant-1;
 
@@ -384,13 +384,13 @@ Read_Commands( void )
 		/* Allocate normalization buffer */
 		{
 		  mreq = (size_t)calc_data.nfrq * sizeof(double);
-		  mem_realloc( (void *)&impedance_data.zreal, mreq, "in input.c" );
-		  mem_realloc( (void *)&impedance_data.zimag, mreq, "in input.c" );
-		  mem_realloc( (void *)&impedance_data.zmagn, mreq, "in input.c" );
-		  mem_realloc( (void *)&impedance_data.zphase, mreq, "in input.c" );
-		  mem_realloc( (void *)&save.freq, mreq, "in input.c" );
+		  mem_realloc( (void **)&impedance_data.zreal, mreq, "in input.c" );
+		  mem_realloc( (void **)&impedance_data.zimag, mreq, "in input.c" );
+		  mem_realloc( (void **)&impedance_data.zmagn, mreq, "in input.c" );
+		  mem_realloc( (void **)&impedance_data.zphase, mreq, "in input.c" );
+		  mem_realloc( (void **)&save.freq, mreq, "in input.c" );
 		  mreq = (size_t)calc_data.nfrq * sizeof(char);
-		  mem_realloc( (void *)&save.fstep, mreq, "in input.c" );
+		  mem_realloc( (void **)&save.fstep, mreq, "in input.c" );
 		}
 
 		if( CHILD ) continue;
@@ -498,15 +498,15 @@ Read_Commands( void )
 		  /* Reallocate loading buffers */
 		  zload.nload++;
 		  mreq = (size_t)zload.nload * sizeof(int);
-		  mem_realloc( (void *)&calc_data.ldtyp,  mreq, "in input.c" );
-		  mem_realloc( (void *)&calc_data.ldtag,  mreq, "in input.c" );
-		  mem_realloc( (void *)&calc_data.ldtagf, mreq, "in input.c" );
-		  mem_realloc( (void *)&calc_data.ldtagt, mreq, "in input.c" );
+		  mem_realloc( (void **)&calc_data.ldtyp,  mreq, "in input.c" );
+		  mem_realloc( (void **)&calc_data.ldtag,  mreq, "in input.c" );
+		  mem_realloc( (void **)&calc_data.ldtagf, mreq, "in input.c" );
+		  mem_realloc( (void **)&calc_data.ldtagt, mreq, "in input.c" );
 
 		  mreq = (size_t)zload.nload * sizeof(double);
-		  mem_realloc( (void *)&calc_data.zlr, mreq, "in input.c" );
-		  mem_realloc( (void *)&calc_data.zli, mreq, "in input.c" );
-		  mem_realloc( (void *)&calc_data.zlc, mreq, "in input.c" );
+		  mem_realloc( (void **)&calc_data.zlr, mreq, "in input.c" );
+		  mem_realloc( (void **)&calc_data.zli, mreq, "in input.c" );
+		  mem_realloc( (void **)&calc_data.zlc, mreq, "in input.c" );
 
 		  idx = zload.nload-1;
 		  calc_data.ldtyp[idx]= itmp1;
@@ -540,8 +540,8 @@ Read_Commands( void )
 			{
 			  nseg = data.n;
 			  mreq = (size_t)(nseg + zload.nldseg) * sizeof(int);
-			  mem_realloc( (void *)&zload.ldsegn, mreq, "in input.c" );
-			  mem_realloc( (void *)&zload.ldtype, mreq, "in input.c" );
+			  mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+			  mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
 			  for( idx = 0; idx < nseg; idx++ )
 			  {
 				zload.ldtype[zload.nldseg]   = itmp1;
@@ -553,8 +553,8 @@ Read_Commands( void )
 			  nseg = itmp4 - itmp3 + 1;
 			  if( nseg <= 0 ) nseg = 1;
 			  mreq = (size_t)(nseg + zload.nldseg) * sizeof(int);
-			  mem_realloc( (void *)&zload.ldsegn, mreq, "in input.c" );
-			  mem_realloc( (void *)&zload.ldtype, mreq, "in input.c" );
+			  mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+			  mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
 			  for( idx = 0; idx < nseg; idx++ )
 			  {
 				zload.ldtype[zload.nldseg]   = itmp1;
@@ -571,8 +571,8 @@ Read_Commands( void )
 				if( data.itag[idx] == itmp2 )
 				{
 				  mreq = (size_t)(zload.nldseg + 1) * sizeof(int);
-				  mem_realloc( (void *)&zload.ldsegn, mreq, "in input.c" );
-				  mem_realloc( (void *)&zload.ldtype, mreq, "in input.c" );
+				  mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+				  mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
 				  zload.ldtype[zload.nldseg]   = itmp1;
 				  zload.ldsegn[zload.nldseg++] = idx+1;
 				}
@@ -582,8 +582,8 @@ Read_Commands( void )
 			  nseg = itmp4 - itmp3 + 1;
 			  if( nseg <= 0 ) nseg = 1; /* Just one seg of tag (=itmp3) */
 			  mreq = (size_t)(zload.nldseg + nseg) * sizeof(int);
-			  mem_realloc( (void *)&zload.ldsegn, mreq, "in input.c" );
-			  mem_realloc( (void *)&zload.ldtype, mreq, "in input.c" );
+			  mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+			  mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
 			  for( idx = 0; idx < nseg; idx++ )
 			  {
 				zload.ldtype[zload.nldseg] = itmp1;
@@ -634,17 +634,17 @@ Read_Commands( void )
 		  /* Re-allocate network buffers */
 		  netcx.nonet++;
 		  mreq = (size_t)netcx.nonet * sizeof(int);
-		  mem_realloc( (void *)&netcx.ntyp,  mreq, "in input.c" );
-		  mem_realloc( (void *)&netcx.iseg1, mreq, "in input.c" );
-		  mem_realloc( (void *)&netcx.iseg2, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.ntyp,  mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.iseg1, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.iseg2, mreq, "in input.c" );
 
 		  mreq = (size_t)netcx.nonet * sizeof(double);
-		  mem_realloc( (void *)&netcx.x11r, mreq, "in input.c" );
-		  mem_realloc( (void *)&netcx.x11i, mreq, "in input.c" );
-		  mem_realloc( (void *)&netcx.x12r, mreq, "in input.c" );
-		  mem_realloc( (void *)&netcx.x12i, mreq, "in input.c" );
-		  mem_realloc( (void *)&netcx.x22r, mreq, "in input.c" );
-		  mem_realloc( (void *)&netcx.x22i, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.x11r, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.x11i, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.x12r, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.x12i, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.x22r, mreq, "in input.c" );
+		  mem_realloc( (void **)&netcx.x22i, mreq, "in input.c" );
 
 		  idx = netcx.nonet-1;
 		  if( ain_num == 12 )
@@ -734,11 +734,6 @@ Read_Commands( void )
 		}
 		if( fpat.iax != 0) fpat.iax = 1;
 		if( fpat.ipd != 0) fpat.ipd = 1;
-		if( (fpat.nth < 2) || (fpat.nph < 1) || (gnd.ifar == 1) )
-		  ClearFlag( ENABLE_RDPAT );
-		else
-		  SetFlag( ENABLE_RDPAT );
-
 		fpat.thets = tmp1;
 		fpat.phis  = tmp2;
 		fpat.dth   = tmp3;
@@ -811,9 +806,15 @@ Read_Commands( void )
 		return( FALSE );
 	} /* switch( ain_num ) */
 
-	/* Allocate radiation pattern buffers */
-	if( isFlagSet(ENABLE_RDPAT) )
+	/* Disable radiation pattern plots */
+	if( (fpat.nth < 2) || (fpat.nph < 1) || (gnd.ifar == 1) )
+	  ClearFlag( ENABLE_RDPAT );
+	else
+	{
+	  /* Allocate radiation pattern buffers */
 	  Alloc_Rdpattern_Buffers( calc_data.nfrq+1, fpat.nth, fpat.nph );
+	  SetFlag( ENABLE_RDPAT );
+	}
 
 	return( TRUE );
   } /* while( TRUE ) */
@@ -843,20 +844,20 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
   *f1 = *f2 = *f3 = *f4 = *f5 = *f6 = 0.0;
 
   /* read a line from input file */
-  mem_alloc((void *)&line_buf, LINE_LEN, "in readgm()");
+  mem_alloc((void **)&line_buf, LINE_LEN, "in readmn()");
   if( line_buf == NULL ) return( FALSE );
   startptr = line_buf;
   eof = Load_Line( line_buf, input_fp );
   if( eof == EOF )
   {
-	Strlcpy( mn, "EN", strlen("EN")+1 );
+	Strlcpy( mn, "EN", 3 );
 	fprintf( stderr,
 		"xnec2c: readmn(): command data card error\n"
 		"Unexpected EOF while reading input file - appending EN card\n" );
 	stop( _("readmn(): Command data card error\n"\
 		  "Unexpected EOF while reading input file\n"\
 			"Uppending a default EN card"), ERR_OK );
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( FALSE );
   }
 
@@ -866,13 +867,13 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
   /* abort if card's mnemonic too short or missing */
   if( len < 2 )
   {
-	Strlcpy( mn, "XX", strlen("XX")+1 );
+	Strlcpy( mn, "XX", 3 );
 	fprintf( stderr,
 		"xnec2c: readmn(): command data card error\n"
 		"card's mnemonic code too short or missing\n" );
 	stop( _("readmn(): Command data card error\n"\
 		  "Mnemonic code too short or missing"), ERR_OK );
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( FALSE );
   }
 
@@ -882,14 +883,14 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
   /* Return if only mnemonic on card */
   if( len == 2 )
   {
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( TRUE );
   }
 
   /* Compatibility with NEC4, comments between data cards */
   if( strncmp(mn, "CM", 2) == 0 )
   {
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( TRUE );
   }
 
@@ -919,7 +920,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
 		mn, line_buf[idx], idx+1 );
 	stop( _("readmn(): Command data card error\n"\
 		  "Spurious character in command card"), ERR_OK );
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( FALSE );
   }
 
@@ -946,7 +947,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
 	*f4= rarr[3];
 	*f5= rarr[4];
 	*f6= rarr[5];
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( TRUE );
   }
 
@@ -971,7 +972,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
   *f5= rarr[4];
   *f6= rarr[5];
 
-  free_ptr( (void *)&startptr );
+  free_ptr( (void **)&startptr );
   return( TRUE );
 } /* readmn() */
 
@@ -998,20 +999,20 @@ readgm( char *gm, int *i1, int *i2, double *x1,
   *x1 = *y1 = *z1 = *x2 = *y2 = *z2 = *rad = 0.0;
 
   /* read a line from input file */
-  mem_alloc((void *)&line_buf, LINE_LEN, "in readgm()");
+  mem_alloc((void **)&line_buf, LINE_LEN, "in readgm()");
   if( line_buf == NULL ) return( FALSE );
   startptr = line_buf;
   eof = Load_Line( line_buf, input_fp );
   if( eof == EOF )
   {
-	Strlcpy( gm, "GE", strlen("GE")+1 );
+	Strlcpy( gm, "GE", 3 );
 	fprintf( stderr,
 		"xnec2c: readgm(): geometry data card error\n"
 		"Unexpected EOF while reading input file - appending GE card\n" );
 	stop( _("readgm(): Geometry data card error\n"\
 		  "Unexpected EOF while reading input file\n"\
 		  "Uppending a default GE card"), ERR_OK );
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( FALSE );
   }
 
@@ -1021,13 +1022,13 @@ readgm( char *gm, int *i1, int *i2, double *x1,
   /* abort if card's mnemonic too short or missing */
   if( len < 2 )
   {
-	Strlcpy( gm, "XX", strlen("XX")+1 );
+	Strlcpy( gm, "XX", 3 );
 	fprintf( stderr,
 		"xnec2c: readgm(): geometry data card error\n"
 		"card's mnemonic code too short or missing\n" );
 	stop( _("readgm(): Geometry data card error\n"\
 		  "Card's mnemonic code too short or missing"), ERR_OK );
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( FALSE );
   }
 
@@ -1037,7 +1038,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
   /* Return if only mnemonic on card */
   if( len == 2 )
   {
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( TRUE );
   }
 
@@ -1045,7 +1046,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
    * comments between data cards */
   if( strcmp(gm, "CM") == 0 )
   {
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( TRUE );
   }
 
@@ -1075,7 +1076,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
 		gm, line_buf[idx], idx+1 );
 	stop( _("readmn(): Geometry data card error\n"\
 		  "Spurious character in command card"), ERR_OK );
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( FALSE );
   }
 
@@ -1101,7 +1102,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
 	*y2 = rarr[4];
 	*z2 = rarr[5];
 	*rad= rarr[6];
-	free_ptr( (void *)&startptr );
+	free_ptr( (void **)&startptr );
 	return( TRUE );
   }
 
@@ -1125,7 +1126,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
   *z2  = rarr[5];
   *rad = rarr[6];
 
-  free_ptr( (void *)&startptr );
+  free_ptr( (void **)&startptr );
   return( TRUE );
 } /* readgm() */
 
@@ -1309,13 +1310,13 @@ datagn( void )
 		{
 		  /* Allocate wire buffers */
 		  mreq = (size_t)data.n * sizeof(double);
-		  mem_realloc( (void *)&data.si,   mreq, "in input.c" );
-		  mem_realloc( (void *)&data.sab,  mreq, "in input.c" );
-		  mem_realloc( (void *)&data.cab,  mreq, "in input.c" );
-		  mem_realloc( (void *)&data.salp, mreq, "in input.c" );
-		  mem_realloc( (void *)&data.x, mreq, "in input.c" );
-		  mem_realloc( (void *)&data.y, mreq, "in input.c" );
-		  mem_realloc( (void *)&data.z, mreq, "in input.c" );
+		  mem_realloc( (void **)&data.si,   mreq, "in input.c" );
+		  mem_realloc( (void **)&data.sab,  mreq, "in input.c" );
+		  mem_realloc( (void **)&data.cab,  mreq, "in input.c" );
+		  mem_realloc( (void **)&data.salp, mreq, "in input.c" );
+		  mem_realloc( (void **)&data.x, mreq, "in input.c" );
+		  mem_realloc( (void **)&data.y, mreq, "in input.c" );
+		  mem_realloc( (void **)&data.z, mreq, "in input.c" );
 
 		  for( i = 0; i < data.n; i++ )
 		  {
@@ -1327,20 +1328,20 @@ datagn( void )
 			data.z[i]=( data.z1[i]+ data.z2[i])/2.0;
 			xw2= xw1* xw1+ yw1* yw1+ zw1* zw1;
 			yw2= sqrt( xw2);
-			yw2=( xw2/ yw2+ yw2)*.5;
+			//yw2=( xw2/yw2 + yw2)/2.0;
 			data.si[i]= yw2;
 			data.cab[i]= xw1/ yw2;
 			data.sab[i]= yw1/ yw2;
+	
 			xw2= zw1/ yw2;
-
 			if( xw2 > 1.0)
 			  xw2=1.0;
 			if( xw2 < -1.0)
 			  xw2=-1.0;
-
 			data.salp[i]= xw2;
-			xw2= asin( xw2)* TD;
-			yw2= atan2( yw1, xw1)* TD;
+
+			//xw2= asin( xw2)* TD;
+			//yw2= atan2( yw1, xw1)* TD;
 
 			if( (data.si[i] <= 1.0e-20) || (data.bi[i] <= 0.0) )
 			{
